package app.views.match.components;

import app.data.entity.Game;
import app.gameimage.GameImageService;
import app.views.match.components.utils.GameComponentUtils;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.html.Div;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import org.springframework.beans.factory.annotation.Autowired;

public class GameCard extends Div {

    private final GameImageService gameImageService;

    private final Game game;

    private final HorizontalLayout inner = new HorizontalLayout();

    private final VerticalLayout left = new VerticalLayout();
    private final Div right = new Div();

    public GameCard(Game game, @Autowired GameImageService gameImageService) {
        this.gameImageService = gameImageService;
        this.game = game;

        addClassName("card");
        addClassName("game-card");

        defineInner();
    }

    ////////////
    // LAYOUT //
    ////////////

    private void defineInner() {
        add(inner);
        inner.add(left, right);
        inner.setAlignItems(FlexComponent.Alignment.CENTER);

        defineLeft();
        defineRight();
    }

    private void defineLeft() {
        Label header = GameComponentUtils.getHeader(game);
        Div timeControlDiv = GameComponentUtils.getTimeControlDiv(game);
        Div blackDiv = GameComponentUtils.getPlayerDiv(game, false);
        Label vsLabel = GameComponentUtils.getVsLabel();
        Div whiteDiv = GameComponentUtils.getPlayerDiv(game, true);
        Button button = GameComponentUtils.getChessComButton(game);

        left.add(header, timeControlDiv, blackDiv, vsLabel, whiteDiv, button);
        left.addClassName("game-info-div");
        left.setAlignItems(FlexComponent.Alignment.CENTER);

        left.setHeightFull();

    }

    private void defineRight() {
        right.addClassName("game-image-div");

        gameImageService.createImageIfNotPresent(game);
        Image image = gameImageService.getImage(game, "Could not load game image.");
        right.add(image);
        image.setWidthFull();
        image.setHeightFull();
    }
}
